@@ -17,12 +17,21 @@
 # 操作失败。
 FAILEDOPERATION = 'FailedOperation'
 
+# 操作失败，账号已欠费隔离。
+FAILEDOPERATION_ACCOUNTISOLATED = 'FailedOperation.AccountIsolated'
+
 # 已分发设备，不能再次创建。
 FAILEDOPERATION_ALREADYDISTRIBUTIONDEVICE = 'FailedOperation.AlreadyDistributionDevice'
 
 # 绑定设备超过限制。
 FAILEDOPERATION_BINDDEVICEOVERLIMIT = 'FailedOperation.BindDeviceOverLimit'
 
+# 单次绑定的设备数量超过限制。
+FAILEDOPERATION_BINDDEVICEPERONCEOVERLIMIT = 'FailedOperation.BindDevicePerOnceOverLimit'
+
+# 广播任务正在执行。
+FAILEDOPERATION_BROADCASTTASKISRUNNING = 'FailedOperation.BroadcastTaskIsRunning'
+
 # 设备已经被禁用。
 FAILEDOPERATION_DEVICEALREADYDISABLED = 'FailedOperation.DeviceAlreadyDisabled'
 
@@ -65,6 +74,9 @@ FAILEDOPERATION_PROXYIPISNOTENOUGH = 'FailedOperation.ProxyIPIsNotEnough'
 # RRPC接口未收到设备端响应。
 FAILEDOPERATION_RRPCTIMEOUT = 'FailedOperation.RRPCTimeout'
 
+# 资源文件MD5或者大小不一致。
+FAILEDOPERATION_RESOURCEFILENOTMATCH = 'FailedOperation.ResourceFileNotMatch'
+
 # 该规则引擎已经是禁用状态，不需要再被禁用。
 FAILEDOPERATION_RULEALREADYDISABLED = 'FailedOperation.RuleAlreadyDisabled'
 
@@ -80,6 +92,9 @@ FAILEDOPERATION_UPDATEVERSIONNOTMATCH = 'FailedOperation.UpdateVersionNotMatch'
 # 内部错误。
 INTERNALERROR = 'InternalError'
 
+# 数据库内部错误。
+INTERNALERROR_DBOPERATIONERROR = 'InternalError.DBOperationError'
+
 # 参数错误。
 INVALIDPARAMETER = 'InvalidParameter'
 
@@ -254,6 +269,9 @@ RESOURCENOTFOUND_TOPICPOLICYNOTEXIST = 'ResourceNotFound.TopicPolicyNotExist'
 # 规则不存在。
 RESOURCENOTFOUND_TOPICRULENOTEXIST = 'ResourceNotFound.TopicRuleNotExist'
 
+# 该产品已存在TID申请，禁止删除。
+UNAUTHORIZEDOPERATION_DELETETIDFAIL = 'UnauthorizedOperation.DeleteTidFail'
+
 # 该设备绑定了网关设备，无法删除。
 UNAUTHORIZEDOPERATION_DEVICEHASALREADYBINDGATEWAY = 'UnauthorizedOperation.DeviceHasAlreadyBindGateway'
 
@@ -287,6 +305,9 @@ UNAUTHORIZEDOPERATION_PRODUCTNOTSUPPORTPSK = 'UnauthorizedOperation.ProductNotSu
 # 用户未通过实名认证。
 UNAUTHORIZEDOPERATION_USERNOTAUTHENTICAED = 'UnauthorizedOperation.UserNotAuthenticaed'
 
+# 设备私钥已被获取。
+UNSUPPORTEDOPERATION_CLIENTCERTALREADYGOT = 'UnsupportedOperation.ClientCertAlreadyGot'
+
 # 设备ota升级中。
 UNSUPPORTEDOPERATION_DEVICEOTATASKINPROGRESS = 'UnsupportedOperation.DeviceOtaTaskInProgress'
 
